
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~
# ~ Acupuncture Data | Confidence Intervals ~
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~

## Download and load the Acupuncture dataset: 
## Note this is a reduced version of the original acupuncture dataset 
## containing all observations but only a limited number of variables
download.file("https://dl.dropboxusercontent.com/u/542394/vickers-data/acupunc_data_reduced.RData",
              destfile = "acupunc_data_reduced.RData",method="internal",mode="wb",cacheOK=FALSE)
load("acupunc_data_reduced.RData")   # the dataset loaded is called 'data'

# Check: Was the data read in correctly?
# - How many observations are in the data 
#   set? Variables?
str(data)

# -----------------------------------------------------

# Goal: Construct 95% confidence intervals for the mean
#       headache severity score at 1 year in each 
#       treatment group. 

# -----------------------------------------------------

# First, must create subsets based on treatment group:
# - How many patients are in each group?
#   (Hint: check the R workspace!)
control <- subset(data,group==0)
treat <- subset(data,group==1)

# -----------------------------------------------------

# Next, check out descriptive stats for headache 
# severity score at 1 year in each treatment group: 
# - What variable corresponds to headache severity 
#   score at 1 year? How do we know?
# - Do you notice anything interesting/important in 
#   the summary stats?
summary(treat$pk5)
summary(control$pk5)

# Create side by side histograms of outcome in each group
par(mfrow=c(1,2))
  
hist(treat$pk5,
     main="Severity at 1yr Treatment Grp",
     xlab="Headache Severity")
hist(control$pk5,
     main="Severity at 1yr Control Grp",
     xlab="Headache Severity")

# -----------------------------------------------------

# Finally, calcuate 95% CI for mean headache
# severity score at 1 year in each group: 
t.test(treat$pk5,conf.level=0.95)
t.test(control$pk5,conf.level=0.95)

# -----------------------------------------------------
# End of program


